binding_organ_symbol

Function binding_organ_symbol 

pub fn binding_organ_symbol() -> Symbol
Symbol identifying the binding organ in the claim store.

Used as the claim subject when publishing the organ’s contributed operations into a Cx.